@@ -295,7 +295,7 @@ static void __litl_open_new_file(litl_write_trace_t* trace) {
 	perror("Cannot open trace file");
 	exit(EXIT_FAILURE);
       }
-    } else {
+     } else {
       fprintf(stderr, "Cannot open %s\n", trace->filename);
       exit(EXIT_FAILURE);
     }
@@ -307,7 +307,7 @@ static void __litl_open_new_file(litl_write_trace_t* trace) {
  */
 static void __litl_write_update_header(litl_write_trace_t* trace) {
   // write the trace header to the trace file
-  assert(trace->f_handle);
+  assert(trace->f_handle >= 0);
   lseek(trace->f_handle, 0, SEEK_SET);
 
   if (write(trace->f_handle, trace->header_ptr,
@@ -322,6 +322,7 @@ static void __litl_write_update_header(litl_write_trace_t* trace) {
  * Update the header and flush it to disk
  */
 static void __litl_write_flush_header(litl_write_trace_t* trace) {
+
   if (!trace->is_header_flushed) {
     // open the trace file
     __litl_open_new_file(trace);
@@ -553,7 +554,7 @@ litl_t* __litl_write_get_event(litl_write_trace_t* trace, litl_type_t type,
 			       litl_code_t code, int param_size) {
   litl_med_size_t index = 0;
   litl_t*retval = NULL;
-  litl_size_t event_size = LITL_BASE_SIZE + param_size;
+  litl_size_t event_size = __litl_get_event_size(type, param_size);
 
   if (trace && trace->is_litl_initialized && !trace->is_recording_paused
     && !trace->is_buffer_full) {
@@ -603,7 +604,6 @@ litl_t* __litl_write_get_event(litl_write_trace_t* trace, litl_type_t type,
       retval = cur_ptr;
       goto out;
     } else if (trace->allow_buffer_flush) {
-
       // not enough space. flush the buffer and retry
       __litl_write_flush_buffer(trace, index);
       retval =  __litl_write_get_event(trace, type, code, param_size);
